summaryrefslogtreecommitdiffstats
path: root/src/lib/dhcpsrv/alloc_engine.h
diff options
context:
space:
mode:
authorMarcin Siodelski <marcin@isc.org>2015-06-26 12:29:25 +0200
committerMarcin Siodelski <marcin@isc.org>2015-06-26 12:29:25 +0200
commit6c489c3e41b80055f2ac76b11ea14addc4a5f4c2 (patch)
tree64804bff864ac7385e28af85c8c6258ae73e7ec9 /src/lib/dhcpsrv/alloc_engine.h
parent[master] ChangeLog updated after 3918 merge. (diff)
downloadkea-6c489c3e41b80055f2ac76b11ea14addc4a5f4c2.tar.xz
kea-6c489c3e41b80055f2ac76b11ea14addc4a5f4c2.zip
[3913] Allocation engine extends the lifetime of the lease for Request.
Diffstat (limited to 'src/lib/dhcpsrv/alloc_engine.h')
-rw-r--r--src/lib/dhcpsrv/alloc_engine.h17
1 files changed, 12 insertions, 5 deletions
diff --git a/src/lib/dhcpsrv/alloc_engine.h b/src/lib/dhcpsrv/alloc_engine.h
index f867f8c8fb..2c2335dbe3 100644
--- a/src/lib/dhcpsrv/alloc_engine.h
+++ b/src/lib/dhcpsrv/alloc_engine.h
@@ -634,19 +634,26 @@ private:
ClientContext6& ctx,
uint8_t prefix_len);
- /// @brief Updates FQDN data for a collection of leases.
+ /// @brief Updates FQDN and Client's Last Tranmission Time for a collection
+ /// of leases.
+ ///
+ /// This method is executed when the server finds existing leases for a
+ /// client and updates some date for these leases if needed:
+ /// - client's last transmission time (cltt), if the lease to be returned
+ /// to the client should have its lifetime extended,
+ /// - FQDN data, when the client has negotiated new FQDN with the server.
///
/// @param ctx IPv6 client context (old versions of the leases that had
/// FQDN data changed will be stored in ctx.changed_leases_,
/// ctx.fwd_dns_update, ctx.rev_dns_update, ctx.hostname_
/// and ctx.fake_allocation_ will be used.
/// @param leases Collection of leases for which FQDN data should be
/// updated.
///
- /// @return Collection of leases with updated FQDN data. Note that returned
+ /// @return Collection of leases with updated data. Note that returned
/// collection holds updated FQDN data even for fake allocation.
- Lease6Collection updateFqdnData(ClientContext6& ctx,
- const Lease6Collection& leases);
+ Lease6Collection updateLeaseData(ClientContext6& ctx,
+ const Lease6Collection& leases);
/// @brief Utility function that removes all leases with a specified address
/// @param container A collection of Lease6 pointers
@@ -634,19 +634,26 @@ private:
/// ctx.fwd_dns_update, ctx.rev_dns_update, ctx.hostname_
/// and ctx.fake_allocation_ will be used.
- /// @param leases Collection of leases for which FQDN data should be
+ /// @param leases Collection of leases for which lease data should be
/// updated.
///